1.0.6 (2026-04-03)
[LEGACY] Compatibility fix to be able to link with bitwuzla-cxx (>= 0.9). Add exists and forall quantifiers to the typed API.
Vendor submodules:
1.0.5 (2023-02-23)
- Enable macOS Homebrew distribution
1.0.4 (2023-02-14)
- Fix an issue with
get_value and assignment when the term is an array or a function
1.0.3 (2022-08-30)
Update Bitwuzla sources.
Vendor submodules:
1.0.2 (2022-06-16)
Update Bitwuzla and its dependencies to more recent versions.
Vendor submodules:
1.0.1 (2021-12-20)
- Fix
timeout function not working properly - Decrease default model generation level (
2 -> 1)
1.0.0 (2021-07-11)
Brand new Bitwuzla OCaml API in addition the low level Bitwuzla_c C API.
Online documentation is available at https://bitwuzla.github.io/docs/ocaml/.
bitwuzla-c package installs C API binding;bitwuzla package installs more OCaml-ish, type safer Bitwuzla API.
Vendor submodules:
0.0.1 (2021-05-24)
0.0.0 (2021-05-20)
Initial release.
OCaml binding for the SMT solver Bitwuzla.
Bitwuzla_c library exposes low level functions from the C API;Bitwuzla_z library converts bitvector value to Zarith integer;bitwuzla-bin package installs Bitwuzla executable.
Vendor submodules: